==> musescore-4.5.2.tar.gz: MuseScore-4.5.2/src/engraving/rendering/score/rendering.cmake <==


set(RENDERING_SCORE_SRC
    ${CMAKE_CURRENT_LIST_DIR}/scorerenderer.cpp
    ${CMAKE_CURRENT_LIST_DIR}/scorerenderer.h
    ${CMAKE_CURRENT_LIST_DIR}/paint.cpp
    ${CMAKE_CURRENT_LIST_DIR}/paint.h
    ${CMAKE_CURRENT_LIST_DIR}/debugpaint.cpp
    ${CMAKE_CURRENT_LIST_DIR}/debugpaint.h
    ${CMAKE_CURRENT_LIST_DIR}/paintdebugger.cpp
    ${CMAKE_CURRENT_LIST_DIR}/paintdebugger.h
    ${CMAKE_CURRENT_LIST_DIR}/tdraw.cpp
    ${CMAKE_CURRENT_LIST_DIR}/tdraw.h
    ${CMAKE_CURRENT_LIST_DIR}/tlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/tlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/layoutcontext.cpp
    ${CMAKE_CURRENT_LIST_DIR}/layoutcontext.h
    ${CMAKE_CURRENT_LIST_DIR}/scorelayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/scorelayout.h
    ${CMAKE_CURRENT_LIST_DIR}/scorepageviewlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/scorepageviewlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/scorehorizontalviewlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/scorehorizontalviewlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/scoreverticalviewlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/scoreverticalviewlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/lyricslayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/lyricslayout.h
    ${CMAKE_CURRENT_LIST_DIR}/measurelayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/measurelayout.h
    ${CMAKE_CURRENT_LIST_DIR}/beamlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/beamlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/beamtremololayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/beamtremololayout.h
    ${CMAKE_CURRENT_LIST_DIR}/chordlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/chordlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/accidentalslayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/accidentalslayout.h
    ${CMAKE_CURRENT_LIST_DIR}/tupletlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/tupletlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/verticalgapdata.cpp
    ${CMAKE_CURRENT_LIST_DIR}/verticalgapdata.h
    ${CMAKE_CURRENT_LIST_DIR}/systemlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/systemlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/harmonylayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/harmonylayout.h
    ${CMAKE_CURRENT_LIST_DIR}/tremololayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/tremololayout.h
    ${CMAKE_CURRENT_LIST_DIR}/pagelayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/pagelayout.h
    ${CMAKE_CURRENT_LIST_DIR}/slurtielayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/slurtielayout.h
    ${CMAKE_CURRENT_LIST_DIR}/guitarbendlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/guitarbendlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/arpeggiolayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/arpeggiolayout.h
    ${CMAKE_CURRENT_LIST_DIR}/horizontalspacing.cpp
    ${CMAKE_CURRENT_LIST_DIR}/horizontalspacing.h
    ${CMAKE_CURRENT_LIST_DIR}/autoplace.cpp
    ${CMAKE_CURRENT_LIST_DIR}/autoplace.h
    ${CMAKE_CURRENT_LIST_DIR}/segmentlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/segmentlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/modifydom.cpp
    ${CMAKE_CURRENT_LIST_DIR}/modifydom.h
    ${CMAKE_CURRENT_LIST_DIR}/alignmentlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/alignmentlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/masklayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/masklayout.h

    ${CMAKE_CURRENT_LIST_DIR}/passbase.cpp
    ${CMAKE_CURRENT_LIST_DIR}/passbase.h
    ${CMAKE_CURRENT_LIST_DIR}/passresetlayoutdata.cpp
    ${CMAKE_CURRENT_LIST_DIR}/passresetlayoutdata.h
    ${CMAKE_CURRENT_LIST_DIR}/passlayoutindependentitems.cpp
    ${CMAKE_CURRENT_LIST_DIR}/passlayoutindependentitems.h

    ${CMAKE_CURRENT_LIST_DIR}/dumplayoutdata.cpp
    ${CMAKE_CURRENT_LIST_DIR}/dumplayoutdata.h
)

==> musescore-4.6.3.tar.gz: MuseScore-4.6.3/src/engraving/rendering/score/rendering.cmake <==


set(RENDERING_SCORE_SRC
    ${CMAKE_CURRENT_LIST_DIR}/scorerenderer.cpp
    ${CMAKE_CURRENT_LIST_DIR}/scorerenderer.h
    ${CMAKE_CURRENT_LIST_DIR}/paint.cpp
    ${CMAKE_CURRENT_LIST_DIR}/paint.h
    ${CMAKE_CURRENT_LIST_DIR}/debugpaint.cpp
    ${CMAKE_CURRENT_LIST_DIR}/debugpaint.h
    ${CMAKE_CURRENT_LIST_DIR}/paintdebugger.cpp
    ${CMAKE_CURRENT_LIST_DIR}/paintdebugger.h
    ${CMAKE_CURRENT_LIST_DIR}/tdraw.cpp
    ${CMAKE_CURRENT_LIST_DIR}/tdraw.h
    ${CMAKE_CURRENT_LIST_DIR}/tlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/tlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/layoutcontext.cpp
    ${CMAKE_CURRENT_LIST_DIR}/layoutcontext.h
    ${CMAKE_CURRENT_LIST_DIR}/scorelayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/scorelayout.h
    ${CMAKE_CURRENT_LIST_DIR}/scorepageviewlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/scorepageviewlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/scorehorizontalviewlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/scorehorizontalviewlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/scoreverticalviewlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/scoreverticalviewlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/lyricslayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/lyricslayout.h
    ${CMAKE_CURRENT_LIST_DIR}/measurelayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/measurelayout.h
    ${CMAKE_CURRENT_LIST_DIR}/beamlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/beamlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/beamtremololayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/beamtremololayout.h
    ${CMAKE_CURRENT_LIST_DIR}/chordlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/chordlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/accidentalslayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/accidentalslayout.h
    ${CMAKE_CURRENT_LIST_DIR}/tupletlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/tupletlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/verticalgapdata.cpp
    ${CMAKE_CURRENT_LIST_DIR}/verticalgapdata.h
    ${CMAKE_CURRENT_LIST_DIR}/systemlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/systemlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/harmonylayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/harmonylayout.h
    ${CMAKE_CURRENT_LIST_DIR}/tremololayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/tremololayout.h
    ${CMAKE_CURRENT_LIST_DIR}/pagelayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/pagelayout.h
    ${CMAKE_CURRENT_LIST_DIR}/slurtielayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/slurtielayout.h
    ${CMAKE_CURRENT_LIST_DIR}/guitarbendlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/guitarbendlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/arpeggiolayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/arpeggiolayout.h
    ${CMAKE_CURRENT_LIST_DIR}/horizontalspacing.cpp
    ${CMAKE_CURRENT_LIST_DIR}/horizontalspacing.h
    ${CMAKE_CURRENT_LIST_DIR}/autoplace.cpp
    ${CMAKE_CURRENT_LIST_DIR}/autoplace.h
    ${CMAKE_CURRENT_LIST_DIR}/segmentlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/segmentlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/modifydom.cpp
    ${CMAKE_CURRENT_LIST_DIR}/modifydom.h
    ${CMAKE_CURRENT_LIST_DIR}/alignmentlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/alignmentlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/masklayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/masklayout.h
    ${CMAKE_CURRENT_LIST_DIR}/dynamicslayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/dynamicslayout.h
    ${CMAKE_CURRENT_LIST_DIR}/stemlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/stemlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/tappinglayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/tappinglayout.h
    ${CMAKE_CURRENT_LIST_DIR}/markerlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/markerlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/measurenumberlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/measurenumberlayout.h
    ${CMAKE_CURRENT_LIST_DIR}/parenthesislayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/parenthesislayout.h
    ${CMAKE_CURRENT_LIST_DIR}/restlayout.cpp
    ${CMAKE_CURRENT_LIST_DIR}/restlayout.h

    ${CMAKE_CURRENT_LIST_DIR}/passbase.cpp
    ${CMAKE_CURRENT_LIST_DIR}/passbase.h
    ${CMAKE_CURRENT_LIST_DIR}/passresetlayoutdata.cpp
    ${CMAKE_CURRENT_LIST_DIR}/passresetlayoutdata.h
    ${CMAKE_CURRENT_LIST_DIR}/passlayoutindependentitems.cpp
    ${CMAKE_CURRENT_LIST_DIR}/passlayoutindependentitems.h

    ${CMAKE_CURRENT_LIST_DIR}/dumplayoutdata.cpp
    ${CMAKE_CURRENT_LIST_DIR}/dumplayoutdata.h
)
